@@ -50,9 +50,10 @@
 #' print(bmr1$combine(bmr2))
 resample = function(task, learner, resampling, store_models = FALSE) {
   task = assert_task(as_task(task, clone = TRUE))
-  learner = assert_learner(as_learner(learner, clone = TRUE), task = task, properties = task$properties)
+  learner = assert_learner(as_learner(learner, clone = TRUE))
   resampling = assert_resampling(as_resampling(resampling))
   assert_flag(store_models)
+  assert_learnable(task, learner)
 
   instance = resampling$clone(deep = TRUE)
   if (!instance$is_instantiated) {
